@@ -9,8 +9,11 @@
  *  Ce programme est un logiciel libre distribué sous licence GNU/GPL.     *
 \***************************************************************************/
 
+use Spip\Afficher\Minipage\Admin as MinipageAdmin;
 use Spip\ErrorHandler;
 
+use function SpipLeague\Component\Kernel\{app, param};
+
 /**
  * Initialisation de SPIP
  *
@@ -35,18 +38,13 @@ error_reporting(E_ALL ^ E_NOTICE);
 
 /** version PHP minimum exigee (cf. inc/utils) */
 define('_PHP_MIN', '7.4.0');
-define('_PHP_MAX', '8.4.99');
-
-if (!defined('_DIR_RESTREINT_ABS')) {
-	/** le nom du repertoire ecrire/ */
-	define('_DIR_RESTREINT_ABS', 'ecrire/');
-}
+define('_PHP_MAX', '8.5.99');
 
 /** Chemin relatif pour aller dans ecrire
  *  vide si on est dans ecrire, 'ecrire/' sinon */
 define(
 	'_DIR_RESTREINT',
-	(!is_dir(_DIR_RESTREINT_ABS) ? '' : _DIR_RESTREINT_ABS)
+	(!is_dir(param('spip.dirs.core')) ? '' : param('spip.dirs.core'))
 );
 
 /** Chemin relatif pour aller à la racine */
@@ -54,10 +52,9 @@ define('_DIR_RACINE', _DIR_RESTREINT ? '' : '../');
 
 /** chemin absolu vers la racine */
 define('_ROOT_RACINE', dirname(__DIR__) . '/');
-/** chemin absolu vers le repertoire de travail */
-define('_ROOT_CWD', getcwd() . '/');
+
 /** chemin absolu vers ecrire */
-define('_ROOT_RESTREINT', _ROOT_CWD . _DIR_RESTREINT);
+define('_ROOT_RESTREINT', app()->getCwd() . DIRECTORY_SEPARATOR . _DIR_RESTREINT);
 
 # Le nom des 4 repertoires modifiables par les scripts lances par httpd
 # Par defaut ces 4 noms seront suffixes par _DIR_RACINE (cf plus bas)
@@ -87,9 +84,6 @@ if (
 	include $f;
 }
 
-// et on peut lancer l'autoloader
-require_once __DIR__ . '/../vendor/autoload.php';
-
 // Icones
 if (!defined('_NOM_IMG_PACK')) {
 	/** Nom du dossier images */
@@ -159,6 +153,7 @@ if (!defined('_IS_BOT')) {
 }
 
 if (!defined('_IS_CLI')) {
+	/** @deprecated 4.4 utiliser PHP_SAPI */
 	define(
 		'_IS_CLI',
 		!isset($_SERVER['HTTP_HOST'])
@@ -364,18 +359,23 @@ $home_server = 'https://www.spip.net';
 # glossaire pour raccourci [?X]. Aussi: [?X#G] et definir glossaire_G
 $url_glossaire_externe = 'https://@lang@.wikipedia.org/wiki/%s';
 
-# TeX
+/**
+ * @deprecated 4.4 will be removed in 5.0, use `mathjax` plugin instead
+**/
 $tex_server = 'https://math.spip.org/tex.php';
-# MathML (pas pour l'instant: manque un bon convertisseur)
-// $mathml_server = 'http://arno.rezo.net/tex2mathml/latex.php';
 
-// Produire du TeX ou du MathML ?
+/**
+ * @deprecated 4.4 will be removed in 5.0, use `mathjax` plugin instead
+**/
 $traiter_math = 'tex';
 
 // Appliquer un indenteur XHTML aux espaces public et/ou prive ?
 $xhtml = false;
 $xml_indent = false;
 
+/**
+ * @deprecated 4.4 call _image_extensions_logos() instead
+ */
 $formats_logos = ['jpg', 'png', 'svg', 'gif', 'webp'];
 
 // Controler les dates des item dans les flux RSS ?
@@ -443,8 +443,8 @@ $liste_des_authentifications = [
 // pour specifier les versions de SPIP necessaires
 // il faut s'en tenir a un nombre de decimales fixe
 // ex : 2.0.0, 2.0.0-dev, 2.0.0-beta, 2.0.0-beta2
-$spip_version_branche = '4.3.8';
-define('_SPIP_VERSION_ID', 40308);
+$spip_version_branche = '4.4.9';
+define('_SPIP_VERSION_ID', 40409);
 define('_SPIP_EXTRA_VERSION', '');
 
 // cette version dev accepte tous les plugins compatible avec la version ci-dessous
@@ -452,7 +452,7 @@ define('_SPIP_EXTRA_VERSION', '');
 # define('_DEV_VERSION_SPIP_COMPAT', '4.1.99');
 // version des signatures de fonctions PHP
 // (= date de leur derniere modif cassant la compatibilite et/ou necessitant un recalcul des squelettes)
-$spip_version_code = 2024_08_01;
+$spip_version_code = 2024_12_03;
 // version de la base SQL (= Date + numero incremental a 2 chiffres YYYYMMDDXX)
 $spip_version_base = 2022_02_23_03;
 
@@ -561,8 +561,8 @@ if (
 		// Si on est dans le site public, dire que qq s'en occupe
 		include_spip('inc/lang');
 		utiliser_langue_visiteur();
-		include_spip('inc/minipres');
-		echo minipres(_T('info_travaux_titre'), "<p style='text-align: center;'>" . _T('info_travaux_texte') . '</p>', ['status' => 503]);
+		$minipage = new MinipageAdmin();
+		echo $minipage->page("<p style='text-align: center;'>" . _T('info_travaux_texte') . '</p>', ['titre' => _T('info_travaux_titre'), 'status' => 503]);
 		exit;
 	}
 	// autrement c'est une install ad hoc (spikini...), on sait pas faire
